@@ -1,4 +1,4 @@
-utils::globalVariables(c("silentText","silentGraph","silentLegend","initialType","ar.orders","i.orders","ma.orders"));
+utils::globalVariables(c("silentText","silentGraph","silentLegend","initialType"));
 
 #' Automatic GUM
 #'
@@ -13,6 +13,9 @@ utils::globalVariables(c("silentText","silentGraph","silentLegend","initialType"
 #' \code{initial="b"}, because optimising GUM of arbitrary order is not a simple
 #' task.
 #'
+#' For some more information about the model and its implementation, see the
+#' vignette: \code{vignette("gum","smooth")}
+#'
 #' @template ssBasicParam
 #' @template ssAdvancedParam
 #' @template ssInitialParam
@@ -22,14 +25,14 @@ utils::globalVariables(c("silentText","silentGraph","silentLegend","initialType"
 #' @template ssGeneralRef
 #' @template ssIntermittentRef
 #'
-#' @param orderMax The value of the max order to check. This is the upper bound
+#' @param orders The value of the max order to check. This is the upper bound
 #' of orders, but the real orders could be lower than this because of the
 #' increasing number of parameters in the models with higher orders.
-#' @param lagMax The value of the maximum lag to check. This should usually be
+#' @param lags The value of the maximum lag to check. This should usually be
 #' a maximum frequency of the data.
-#' @param type Type of model. Can either be \code{"Additive"} or
-#' \code{"Multiplicative"}. The latter means that the GUM is fitted on
-#' log-transformed data. If \code{"Z"}, then this is selected automatically,
+#' @param type Type of model. Can either be \code{"additive"} or
+#' \code{"multiplicative"}. The latter means that the GUM is fitted on
+#' log-transformed data. If \code{"select"}, then this is selected automatically,
 #' which may slow down things twice.
 #' @param ...  Other non-documented parameters. For example \code{FI=TRUE} will
 #' make the function also produce Fisher Information matrix, which then can be
@@ -44,7 +47,7 @@ utils::globalVariables(c("silentText","silentGraph","silentLegend","initialType"
 #' x <- rnorm(50,100,3)
 #'
 #' # The best GUM model for the data
-#' ourModel <- auto.gum(x,orderMax=2,lagMax=4,h=18,holdout=TRUE,intervals="np")
+#' ourModel <- auto.gum(x,orders=2,lags=4,h=18,holdout=TRUE,interval="np")
 #'
 #' summary(ourModel)
 #' forecast(ourModel)
@@ -52,11 +55,11 @@ utils::globalVariables(c("silentText","silentGraph","silentLegend","initialType"
 #'
 #'
 #' @export auto.gum
-auto.gum <- function(data, orderMax=3, lagMax=frequency(data), type=c("A","M","Z"),
+auto.gum <- function(y, orders=3, lags=frequency(y), type=c("additive","multiplicative","select"),
                      initial=c("backcasting","optimal"), ic=c("AICc","AIC","BIC","BICc"),
-                     cfType=c("MSE","MAE","HAM","MSEh","TMSE","GTMSE","MSCE"),
+                     loss=c("MSE","MAE","HAM","MSEh","TMSE","GTMSE","MSCE"),
                      h=10, holdout=FALSE, cumulative=FALSE,
-                     intervals=c("none","parametric","semiparametric","nonparametric"), level=0.95,
+                     interval=c("none","parametric","semiparametric","nonparametric"), level=0.95,
                      occurrence=c("none","auto","fixed","general","odds-ratio","inverse-odds-ratio","direct"),
                      oesmodel="MNN",
                      bounds=c("restricted","admissible","none"),
@@ -70,38 +73,50 @@ auto.gum <- function(data, orderMax=3, lagMax=frequency(data), type=c("A","M","Z
 # Start measuring the time of calculations
     startTime <- Sys.time();
 
+    ##### Check if data was used instead of y. Remove by 2.6.0 #####
+    y <- depricator(y, list(...), "data");
+    loss <- depricator(loss, list(...), "cfType");
+    interval <- depricator(interval, list(...), "intervals");
+    orders <- depricator(orders, list(...), "ordersMax");
+    lags <- depricator(lags, list(...), "lagsMax");
+
 # Add all the variables in ellipsis to current environment
     list2env(list(...),environment());
 
+    # If this is Mcomp data, then take the frequency from it
+    if(any(class(y)=="Mdata") && lags==frequency(y)){
+        lags <- frequency(y$x);
+    }
+
 ##### Set environment for ssInput and make all the checks #####
     environment(ssAutoInput) <- environment();
     ssAutoInput("auto.gum",ParentEnvironment=environment());
 
-    if(any(is.complex(c(orderMax,lagMax)))){
+    if(any(is.complex(c(orders,lags)))){
         stop("Complex numbers? Really? Be serious! This is GUM, not CES!",call.=FALSE);
     }
 
-    if(any(c(orderMax)<0)){
+    if(any(c(orders)<0)){
         stop("Funny guy! How am I gonna construct a model with negative maximum order?",call.=FALSE);
     }
 
-    if(any(c(lagMax)<0)){
+    if(any(c(lags)<0)){
         stop("Right! Why don't you try complex lags then, mister smart guy?",call.=FALSE);
     }
 
-    if(any(c(lagMax,orderMax)==0)){
+    if(any(c(lags,orders)==0)){
         stop("Sorry, but we cannot construct GUM model with zero lags / orders.",call.=FALSE);
     }
 
     type <- substr(type[1],1,1);
     # Check if the multiplictive model is possible
-    if(any(type==c("Z","M"))){
-        if(any(y<=0)){
+    if(any(type==c("s","m"))){
+        if(any(yInSample<=0)){
             warning("Multiplicative model can only be used on positive data. Switching to the additive one.",call.=FALSE);
-            type <- "A";
+            type <- "a";
         }
-        if(type=="Z"){
-            type <- c("A","M");
+        if(type=="s"){
+            type <- c("a","m");
         }
     }
 
@@ -110,23 +125,23 @@ auto.gum <- function(data, orderMax=3, lagMax=frequency(data), type=c("A","M","Z
     ordersFinal <- list(NA);
 
     if(!silentText){
-        if(lagMax>12){
-            message(paste0("You have large lagMax: ",lagMax,". So, the calculation may take some time."));
-            if(lagMax<24){
+        if(lags>12){
+            message(paste0("You have large lags: ",lags,". So, the calculation may take some time."));
+            if(lags<24){
                 message(paste0("Go get some coffee, or tea, or whatever, while we do the work here.\n"));
             }
             else{
                 message(paste0("Go for a lunch or something, while we do the work here.\n"));
             }
         }
-        if(orderMax>3){
-            message(paste0("Beware that you have specified large orderMax: ",orderMax,
+        if(orders>3){
+            message(paste0("Beware that you have specified large orders: ",orders,
                            ". This means that the calculations may take a lot of time.\n"));
         }
     }
 
     for(t in 1:length(type)){
-        ics <- rep(NA,lagMax);
+        ics <- rep(NA,lags);
         lagsBest <- NULL
 
         if((!silentText) & length(type)!=1){
@@ -134,26 +149,26 @@ auto.gum <- function(data, orderMax=3, lagMax=frequency(data), type=c("A","M","Z
         }
 
     #### Preliminary loop ####
-        #Checking all the models with lag from 1 to lagMax
+        #Checking all the models with lag from 1 to lags
         if(!silentText){
             progressBar <- c("/","\u2014","\\","|");
             cat("Starting preliminary loop: ");
-            cat(paste0(rep(" ",9+nchar(lagMax)),collapse=""));
+            cat(paste0(rep(" ",9+nchar(lags)),collapse=""));
         }
-        for(i in 1:lagMax){
-            gumModel <- gum(data,orders=c(1),lags=c(i),type=type[t],
+        for(i in 1:lags){
+            gumModel <- gum(y,orders=c(1),lags=c(i),type=type[t],
                             silent=TRUE,h=h,holdout=holdout,
-                            initial=initial,cfType=cfType,
+                            initial=initial,loss=loss,
                             cumulative=cumulative,
-                            intervals=intervalsType, level=level,
+                            interval=intervalType, level=level,
                             occurrence=occurrence, oesmodel=oesmodel,
                             bounds=bounds,
                             xreg=xreg, xregDo=xregDo, initialX=initialX,
                             updateX=updateX, persistenceX=persistenceX, transitionX=transitionX, ...);
             ics[i] <- gumModel$ICs[ic];
             if(!silentText){
-                cat(paste0(rep("\b",nchar(paste0(i-1," out of ",lagMax))),collapse=""));
-                cat(paste0(i," out of ",lagMax));
+                cat(paste0(rep("\b",nchar(paste0(i-1," out of ",lags))),collapse=""));
+                cat(paste0(i," out of ",lags));
             }
         }
 
@@ -165,7 +180,7 @@ auto.gum <- function(data, orderMax=3, lagMax=frequency(data), type=c("A","M","Z
         lagsBest <- c(which(ics==min(ics)),lagsBest);
         icsBest <- 1E100;
         while(min(ics)<icsBest){
-            for(i in 1:lagMax){
+            for(i in 1:lags){
                 if(!silentText){
                     cat("\b");
                     cat(progressBar[(i/4-floor(i/4))*4+1]);
@@ -182,11 +197,11 @@ auto.gum <- function(data, orderMax=3, lagMax=frequency(data), type=c("A","M","Z
                     ics[i] <- 1E100;
                     next;
                 }
-                gumModel <- gum(data,orders=ordersTest,lags=lagsTest,type=type[t],
+                gumModel <- gum(y,orders=ordersTest,lags=lagsTest,type=type[t],
                                 silent=TRUE,h=h,holdout=holdout,
-                                initial=initial,cfType=cfType,
+                                initial=initial,loss=loss,
                                 cumulative=cumulative,
-                                intervals=intervalsType, level=level,
+                                interval=intervalType, level=level,
                                 occurrence=occurrence, oesmodel=oesmodel,
                                 bounds=bounds,
                                 xreg=xreg, xregDo=xregDo, initialX=initialX,
@@ -206,7 +221,7 @@ auto.gum <- function(data, orderMax=3, lagMax=frequency(data), type=c("A","M","Z
             cat("Searching for appropriate orders:  ");
         }
         icsBest <- min(ics);
-        ics <- array(c(1:(orderMax^length(lagsBest))),rep(orderMax,length(lagsBest)));
+        ics <- array(c(1:(orders^length(lagsBest))),rep(orders,length(lagsBest)));
         ics[1] <- icsBest;
         for(i in 1:length(ics)){
             if(!silentText){
@@ -224,11 +239,11 @@ auto.gum <- function(data, orderMax=3, lagMax=frequency(data), type=c("A","M","Z
                 ics[i] <- NA;
                 next;
             }
-            gumModel <- gum(data,orders=ordersTest,lags=lagsBest,type=type[t],
+            gumModel <- gum(y,orders=ordersTest,lags=lagsBest,type=type[t],
                             silent=TRUE,h=h,holdout=holdout,
-                            initial=initial,cfType=cfType,
+                            initial=initial,loss=loss,
                             cumulative=cumulative,
-                            intervals=intervalsType, level=level,
+                            interval=intervalType, level=level,
                             occurrence=occurrence, oesmodel=oesmodel,
                             bounds=bounds,
                             xreg=xreg, xregDo=xregDo, initialX=initialX,
@@ -251,11 +266,11 @@ auto.gum <- function(data, orderMax=3, lagMax=frequency(data), type=c("A","M","Z
         cat("Reestimating the model. ");
     }
 
-    bestModel <- gum(data,orders=ordersFinal[[t]],lags=lagsFinal[[t]],type=type[t],
+    bestModel <- gum(y,orders=ordersFinal[[t]],lags=lagsFinal[[t]],type=type[t],
                      silent=TRUE,h=h,holdout=holdout,
-                     initial=initial,cfType=cfType,
+                     initial=initial,loss=loss,
                      cumulative=cumulative,
-                     intervals=intervalsType, level=level,
+                     interval=intervalType, level=level,
                      occurrence=occurrence, oesmodel=oesmodel,
                      bounds=bounds,
                      xreg=xreg, xregDo=xregDo, initialX=initialX,
@@ -279,19 +294,19 @@ auto.gum <- function(data, orderMax=3, lagMax=frequency(data), type=c("A","M","Z
         yUpperNew <- yUpper;
         yLowerNew <- yLower;
         if(cumulative){
-            yForecastNew <- ts(rep(yForecast/h,h),start=start(yForecast),frequency=dataFreq);
-            if(intervals){
-                yUpperNew <- ts(rep(yUpper/h,h),start=start(yForecast),frequency=dataFreq);
-                yLowerNew <- ts(rep(yLower/h,h),start=start(yForecast),frequency=dataFreq);
+            yForecastNew <- ts(rep(yForecast/h,h),start=yForecastStart,frequency=dataFreq);
+            if(interval){
+                yUpperNew <- ts(rep(yUpper/h,h),start=yForecastStart,frequency=dataFreq);
+                yLowerNew <- ts(rep(yLower/h,h),start=yForecastStart,frequency=dataFreq);
             }
         }
 
-        if(intervals){
-            graphmaker(actuals=data,forecast=yForecastNew,fitted=yFitted, lower=yLowerNew,upper=yUpperNew,
+        if(interval){
+            graphmaker(actuals=y,forecast=yForecastNew,fitted=yFitted, lower=yLowerNew,upper=yUpperNew,
                        level=level,legend=!silentLegend,main=modelname,cumulative=cumulative);
         }
         else{
-            graphmaker(actuals=data,forecast=yForecastNew,fitted=yFitted,
+            graphmaker(actuals=y,forecast=yForecastNew,fitted=yFitted,
                        legend=!silentLegend,main=modelname,cumulative=cumulative);
         }
     }
