@@ -1,5 +1,5 @@
 utils::globalVariables(c("measurementEstimate","transitionEstimate", "C",
-                         "persistenceEstimate","obsAll","obsInsample","multisteps","ot","obsNonzero","ICs","cfObjective",
+                         "persistenceEstimate","obsAll","obsInSample","multisteps","ot","obsNonzero","ICs","cfObjective",
                          "yForecast","yLower","yUpper","normalizer","yForecastStart"));
 
 #' Generalised Univariate Model
@@ -25,6 +25,8 @@ utils::globalVariables(c("measurementEstimate","transitionEstimate", "C",
 #' \eqn{F_{X}} is the \code{transitionX} matrix and \eqn{g_{X}} is the
 #' \code{persistenceX} matrix. Finally, \eqn{\epsilon_{t}} is the error term.
 #'
+#' For some more information about the model and its implementation, see the
+#' vignette: \code{vignette("gum","smooth")}
 #'
 #' @template ssBasicParam
 #' @template ssAdvancedParam
@@ -83,17 +85,17 @@ utils::globalVariables(c("measurementEstimate","transitionEstimate", "C",
 #' \item \code{fitted} - fitted values.
 #' \item \code{forecast} - point forecast.
 #' \item \code{lower} - lower bound of prediction interval. When
-#' \code{intervals="none"} then NA is returned.
+#' \code{interval="none"} then NA is returned.
 #' \item \code{upper} - higher bound of prediction interval. When
-#' \code{intervals="none"} then NA is returned.
+#' \code{interval="none"} then NA is returned.
 #' \item \code{residuals} - the residuals of the estimated model.
 #' \item \code{errors} - matrix of 1 to h steps ahead errors.
 #' \item \code{s2} - variance of the residuals (taking degrees of freedom
 #' into account).
-#' \item \code{intervals} - type of intervals asked by user.
-#' \item \code{level} - confidence level for intervals.
+#' \item \code{interval} - type of interval asked by user.
+#' \item \code{level} - confidence level for interval.
 #' \item \code{cumulative} - whether the produced forecast was cumulative or not.
-#' \item \code{actuals} - original data.
+#' \item \code{y} - original data.
 #' \item \code{holdout} - holdout part of the original data.
 #' \item \code{occurrence} - model of the class "oes" if the occurrence model was estimated.
 #' If the model is non-intermittent, then occurrence is \code{NULL}.
@@ -107,8 +109,8 @@ utils::globalVariables(c("measurementEstimate","transitionEstimate", "C",
 #' \item \code{ICs} - values of information criteria of the model. Includes
 #' AIC, AICc, BIC and BICc.
 #' \item \code{logLik} - log-likelihood of the function.
-#' \item \code{cf} - Cost function value.
-#' \item \code{cfType} - Type of cost function used in the estimation.
+#' \item \code{lossValue} - Cost function value.
+#' \item \code{loss} - Type of loss function used in the estimation.
 #' \item \code{FI} - Fisher Information. Equal to NULL if \code{FI=FALSE} or
 #' when \code{FI} variable is not provided at all.
 #' \item \code{accuracy} - vector of accuracy measures for the holdout sample.
@@ -124,20 +126,20 @@ utils::globalVariables(c("measurementEstimate","transitionEstimate", "C",
 #' @examples
 #'
 #' # Something simple:
-#' gum(rnorm(118,100,3),orders=c(1),lags=c(1),h=18,holdout=TRUE,bounds="a",intervals="p")
+#' gum(rnorm(118,100,3),orders=c(1),lags=c(1),h=18,holdout=TRUE,bounds="a",interval="p")
 #'
 #' # A more complicated model with seasonality
 #' \dontrun{ourModel <- gum(rnorm(118,100,3),orders=c(2,1),lags=c(1,4),h=18,holdout=TRUE)}
 #'
-#' # Redo previous model on a new data and produce prediction intervals
-#' \dontrun{gum(rnorm(118,100,3),model=ourModel,h=18,intervals="sp")}
+#' # Redo previous model on a new data and produce prediction interval
+#' \dontrun{gum(rnorm(118,100,3),model=ourModel,h=18,interval="sp")}
 #'
 #' # Produce something crazy with optimal initials (not recommended)
 #' \dontrun{gum(rnorm(118,100,3),orders=c(1,1,1),lags=c(1,3,5),h=18,holdout=TRUE,initial="o")}
 #'
-#' # Simpler model estiamted using trace forecast error cost function and its analytical analogue
-#' \dontrun{gum(rnorm(118,100,3),orders=c(1),lags=c(1),h=18,holdout=TRUE,bounds="n",cfType="TMSE")
-#' gum(rnorm(118,100,3),orders=c(1),lags=c(1),h=18,holdout=TRUE,bounds="n",cfType="aTMSE")}
+#' # Simpler model estiamted using trace forecast error loss function and its analytical analogue
+#' \dontrun{gum(rnorm(118,100,3),orders=c(1),lags=c(1),h=18,holdout=TRUE,bounds="n",loss="TMSE")
+#' gum(rnorm(118,100,3),orders=c(1),lags=c(1),h=18,holdout=TRUE,bounds="n",loss="aTMSE")}
 #'
 #' # Introduce exogenous variables
 #' \dontrun{gum(rnorm(118,100,3),orders=c(1),lags=c(1),h=18,holdout=TRUE,xreg=c(1:118))}
@@ -146,8 +148,8 @@ utils::globalVariables(c("measurementEstimate","transitionEstimate", "C",
 #' \dontrun{gum(rnorm(118,100,3),orders=c(1),lags=c(1),h=18,holdout=TRUE,xreg=c(1:118),updateX=TRUE)}
 #'
 #' # Do the same but now let's shrink parameters...
-#' \dontrun{gum(rnorm(118,100,3),orders=c(1),lags=c(1),h=18,xreg=c(1:118),updateX=TRUE,cfType="TMSE")
-#' ourModel <- gum(rnorm(118,100,3),orders=c(1),lags=c(1),h=18,holdout=TRUE,cfType="aTMSE")}
+#' \dontrun{gum(rnorm(118,100,3),orders=c(1),lags=c(1),h=18,xreg=c(1:118),updateX=TRUE,loss="TMSE")
+#' ourModel <- gum(rnorm(118,100,3),orders=c(1),lags=c(1),h=18,holdout=TRUE,loss="aTMSE")}
 #'
 #' # Or select the most appropriate one
 #' \dontrun{gum(rnorm(118,100,3),orders=c(1),lags=c(1),h=18,holdout=TRUE,xreg=c(1:118),xregDo="s")
@@ -158,12 +160,12 @@ utils::globalVariables(c("measurementEstimate","transitionEstimate", "C",
 #'
 #' @rdname gum
 #' @export gum
-gum <- function(data, orders=c(1,1), lags=c(1,frequency(data)), type=c("A","M"),
+gum <- function(y, orders=c(1,1), lags=c(1,frequency(y)), type=c("additive","multiplicative"),
                 persistence=NULL, transition=NULL, measurement=NULL,
                 initial=c("optimal","backcasting"), ic=c("AICc","AIC","BIC","BICc"),
-                cfType=c("MSE","MAE","HAM","MSEh","TMSE","GTMSE","MSCE"),
+                loss=c("MSE","MAE","HAM","MSEh","TMSE","GTMSE","MSCE"),
                 h=10, holdout=FALSE, cumulative=FALSE,
-                intervals=c("none","parametric","semiparametric","nonparametric"), level=0.95,
+                interval=c("none","parametric","semiparametric","nonparametric"), level=0.95,
                 occurrence=c("none","auto","fixed","general","odds-ratio","inverse-odds-ratio","direct"),
                 oesmodel="MNN",
                 bounds=c("restricted","admissible","none"),
@@ -177,6 +179,11 @@ gum <- function(data, orders=c(1,1), lags=c(1,frequency(data)), type=c("A","M"),
 # Start measuring the time of calculations
     startTime <- Sys.time();
 
+    ##### Check if data was used instead of y. Remove by 2.6.0 #####
+    y <- depricator(y, list(...), "data");
+    loss <- depricator(loss, list(...), "cfType");
+    interval <- depricator(interval, list(...), "intervals");
+
 # Add all the variables in ellipsis to current environment
     list2env(list(...),environment());
 
@@ -318,9 +325,9 @@ CF <- function(C){
     matFX <- elements$matFX;
     vecgX <- elements$vecgX;
 
-    cfRes <- costfunc(matvt, matF, matw, y, vecg,
+    cfRes <- costfunc(matvt, matF, matw, yInSample, vecg,
                        h, modellags, Etype, Ttype, Stype,
-                       multisteps, cfType, normalizer, initialType,
+                       multisteps, loss, normalizer, initialType,
                        matxt, matat, matFX, vecgX, ot,
                        bounds, 0);
 
@@ -459,14 +466,14 @@ CreatorGUM <- function(silentText=FALSE,...){
 
 ##### Preset yFitted, yForecast, errors and basic parameters #####
     matvt <- matrix(NA,nrow=obsStates,ncol=nComponents);
-    yFitted <- rep(NA,obsInsample);
+    yFitted <- rep(NA,obsInSample);
     yForecast <- rep(NA,h);
-    errors <- rep(NA,obsInsample);
+    errors <- rep(NA,obsInSample);
 
 ##### Prepare exogenous variables #####
-    xregdata <- ssXreg(data=data, xreg=xreg, updateX=updateX, ot=ot,
+    xregdata <- ssXreg(y=y, xreg=xreg, updateX=updateX, ot=ot,
                        persistenceX=persistenceX, transitionX=transitionX, initialX=initialX,
-                       obsInsample=obsInsample, obsAll=obsAll, obsStates=obsStates,
+                       obsInSample=obsInSample, obsAll=obsAll, obsStates=obsStates,
                        maxlag=maxlag, h=h, xregDo=xregDo, silent=silentText);
 
     if(xregDo=="u"){
@@ -546,9 +553,9 @@ CreatorGUM <- function(silentText=FALSE,...){
 # If this is tiny sample, use SES instead
     if(tinySample){
         warning("Not enough observations to fit GUM Switching to ETS(A,N,N).",call.=FALSE);
-        return(es(data,"ANN",initial=initial,cfType=cfType,
+        return(es(y,"ANN",initial=initial,loss=loss,
                   h=h,holdout=holdout,cumulative=cumulative,
-                  intervals=intervals,level=level,
+                  interval=interval,level=level,
                   occurrence=occurrence,
                   oesmodel=oesmodel,
                   bounds="u",
@@ -748,7 +755,7 @@ CreatorGUM <- function(silentText=FALSE,...){
     ssForecaster(ParentEnvironment=environment());
 
     if(modelIsMultiplicative){
-        y <- exp(y);
+        yInSample <- exp(yInSample);
         yFitted <- exp(yFitted);
         yForecast <- exp(yForecast);
         yLower <- exp(yLower);
@@ -807,7 +814,7 @@ CreatorGUM <- function(silentText=FALSE,...){
     }
 
 # Make some preparations
-    matvt <- ts(matvt,start=(time(data)[1] - deltat(data)*maxlag),frequency=frequency(data));
+    matvt <- ts(matvt,start=(time(y)[1] - deltat(y)*maxlag),frequency=dataFreq);
     if(!is.null(xreg)){
         matvt <- cbind(matvt,matat);
         colnames(matvt) <- c(paste0("Component ",c(1:nComponents)),colnames(matat));
@@ -834,12 +841,12 @@ CreatorGUM <- function(silentText=FALSE,...){
 
 ##### Deal with the holdout sample #####
     if(holdout){
-        yHoldout <- ts(data[(obsInsample+1):obsAll],start=yForecastStart,frequency=frequency(data));
+        yHoldout <- ts(y[(obsInSample+1):obsAll],start=yForecastStart,frequency=dataFreq);
         if(cumulative){
-            errormeasures <- measures(sum(yHoldout),yForecast,h*y);
+            errormeasures <- measures(sum(yHoldout),yForecast,h*yInSample);
         }
         else{
-            errormeasures <- measures(yHoldout,yForecast,y);
+            errormeasures <- measures(yHoldout,yForecast,yInSample);
         }
 
         if(cumulative){
@@ -887,18 +894,18 @@ CreatorGUM <- function(silentText=FALSE,...){
         yLowerNew <- yLower;
         if(cumulative){
             yForecastNew <- ts(rep(yForecast/h,h),start=yForecastStart,frequency=dataFreq)
-            if(intervals){
+            if(interval){
                 yUpperNew <- ts(rep(yUpper/h,h),start=yForecastStart,frequency=dataFreq)
                 yLowerNew <- ts(rep(yLower/h,h),start=yForecastStart,frequency=dataFreq)
             }
         }
 
-        if(intervals){
-            graphmaker(actuals=data,forecast=yForecastNew,fitted=yFitted, lower=yLowerNew,upper=yUpperNew,
+        if(interval){
+            graphmaker(actuals=y,forecast=yForecastNew,fitted=yFitted, lower=yLowerNew,upper=yUpperNew,
                        level=level,legend=!silentLegend,main=modelname,cumulative=cumulative);
         }
         else{
-            graphmaker(actuals=data,forecast=yForecastNew,fitted=yFitted,
+            graphmaker(actuals=y,forecast=yForecastNew,fitted=yFitted,
                        legend=!silentLegend,main=modelname,cumulative=cumulative);
         }
     }
@@ -909,10 +916,10 @@ CreatorGUM <- function(silentText=FALSE,...){
                   initialType=initialType,initial=initialValue,
                   nParam=parametersNumber,
                   fitted=yFitted,forecast=yForecast,lower=yLower,upper=yUpper,residuals=errors,
-                  errors=errors.mat,s2=s2,intervals=intervalsType,level=level,cumulative=cumulative,
-                  actuals=data,holdout=yHoldout,occurrence=occurrenceModel,
+                  errors=errors.mat,s2=s2,interval=intervalType,level=level,cumulative=cumulative,
+                  y=y,holdout=yHoldout,occurrence=occurrenceModel,
                   xreg=xreg,updateX=updateX,initialX=initialX,persistenceX=persistenceX,transitionX=transitionX,
-                  ICs=ICs,logLik=logLik,cf=cfObjective,cfType=cfType,FI=FI,accuracy=errormeasures);
+                  ICs=ICs,logLik=logLik,lossValue=cfObjective,loss=loss,FI=FI,accuracy=errormeasures);
     return(structure(model,class="smooth"));
 }
 
